summaryrefslogtreecommitdiffstats
path: root/tdecore/tdeconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tdeconfig.h')
-rw-r--r--tdecore/tdeconfig.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/tdecore/tdeconfig.h b/tdecore/tdeconfig.h
index 77a009efa..59f784107 100644
--- a/tdecore/tdeconfig.h
+++ b/tdecore/tdeconfig.h
@@ -267,14 +267,14 @@ private:
/**
* TDEConfig variant using shared memory
*
* KSharedConfig provides a reference counted, shared memory variant
* of TDEConfig.
*/
-class TDECORE_EXPORT KSharedConfig : public TDEConfig, public KShared
+class TDECORE_EXPORT TDESharedConfig : public TDEConfig, public TDEShared
{
- friend class TQValueList<KSharedConfig*>;
+ friend class TQValueList<TDESharedConfig*>;
public:
- typedef KSharedPtr<KSharedConfig> Ptr;
+ typedef TDESharedPtr<TDESharedConfig> Ptr;
public:
/**
@@ -283,14 +283,14 @@ public:
* @param readOnly set the config object's read-only status
* @param bUseKDEGlobals Toggle reading the global KDE configuration file.
*/
- static KSharedConfig::Ptr openConfig(const TQString& fileName, bool readOnly = false,
+ static TDESharedConfig::Ptr openConfig(const TQString& fileName, bool readOnly = false,
bool bUseKDEGlobals = true);
private:
- KSharedConfig( const TQString& fileName, bool readOnly, bool useKDEGlobals );
- ~KSharedConfig();
+ TDESharedConfig( const TQString& fileName, bool readOnly, bool useKDEGlobals );
+ ~TDESharedConfig();
- static TQValueList<KSharedConfig*> *s_list;
+ static TQValueList<TDESharedConfig*> *s_list;
};
#endif
@@ -267,14 +267,14 @@ private:
* TDEConfig variant using shared memory
*
- * KSharedConfig provides a reference counted, shared memory variant
+ * TDESharedConfig provides a reference counted, shared memory variant
* of TDEConfig.
*/